@@ -1,4 +1,3 @@
-
 test_that("get_zip_data", {
   on.exit(try(unlink(tmp, recursive = TRUE)), add = TRUE)
   dir.create(tmp <- tempfile())
@@ -16,25 +15,27 @@ test_that("get_zip_data", {
     get_zip_data_path_recursive(foobar),
     df(foobar, normalizePath(foobar), FALSE)
   )
-  expect_equal(get_zip_data_path_recursive(foobar), get_zip_data_path(foobar, TRUE))
+  expect_equal(
+    get_zip_data_path_recursive(foobar),
+    get_zip_data_path(foobar, TRUE)
+  )
 
   expect_equal(
     get_zip_data_path_recursive(tmp),
-    df(c(paste0(tmp, "/"), file.path(tmp, "foobar")),
-       normalizePath(c(tmp, foobar)),
-       c(TRUE, FALSE)
-       )
+    df(
+      c(paste0(tmp, "/"), file.path(tmp, "foobar")),
+      normalizePath(c(tmp, foobar)),
+      c(TRUE, FALSE)
+    )
   )
   expect_equal(get_zip_data_path_recursive(tmp), get_zip_data_path(tmp, TRUE))
 
   expect_equal(
     withr::with_dir(tmp, get_zip_data_path_recursive(".")),
-    df(c("./", "./foobar"),
-       normalizePath(c(tmp, foobar)),
-       c(TRUE, FALSE)
-       )
+    df(c("./", "./foobar"), normalizePath(c(tmp, foobar)), c(TRUE, FALSE))
   )
-  withr::with_dir(tmp,
+  withr::with_dir(
+    tmp,
     expect_equal(get_zip_data_path_recursive("."), get_zip_data_path(".", TRUE))
   )
 
@@ -44,21 +45,27 @@ test_that("get_zip_data", {
   cat("bar\n", file = bar)
 
   data <- df(
-    c(paste0(tmp, "/"),
+    c(
+      paste0(tmp, "/"),
       paste0(file.path(tmp, "empty"), "/"),
       paste0(file.path(tmp, "foo"), "/"),
       file.path(tmp, "foo", "bar"),
-      file.path(tmp, "foobar")),
+      file.path(tmp, "foobar")
+    ),
     normalizePath(c(
-      tmp, file.path(tmp, "empty"), file.path(tmp, "foo"),
-      bar, file.path(tmp, "foobar"))),
+      tmp,
+      file.path(tmp, "empty"),
+      file.path(tmp, "foo"),
+      bar,
+      file.path(tmp, "foobar")
+    )),
     c(TRUE, TRUE, TRUE, FALSE, FALSE)
   )
   data <- data[order(data$file), ]
   rownames(data) <- NULL
 
   data2 <- get_zip_data_path_recursive(tmp)
-  data2  <- data2[order(data2$file), ]
+  data2 <- data2[order(data2$file), ]
   rownames(data2) <- NULL
 
   expect_equal(data2, data)
@@ -66,22 +73,20 @@ test_that("get_zip_data", {
 
   expect_equal(
     get_zip_data_path(c(foobar, bar), TRUE),
-    df(c(foobar, bar),
-       normalizePath(c(foobar, bar)),
-       c(FALSE, FALSE))
+    df(c(foobar, bar), normalizePath(c(foobar, bar)), c(FALSE, FALSE))
   )
 
   expect_equal(
     get_zip_data_path(file.path(tmp, "foo"), TRUE),
-    df(c(paste0(file.path(tmp, "foo"), "/"), file.path(tmp, "foo", "bar")),
-       normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
-       c(TRUE, FALSE)
-       )
+    df(
+      c(paste0(file.path(tmp, "foo"), "/"), file.path(tmp, "foo", "bar")),
+      normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
+      c(TRUE, FALSE)
+    )
   )
 })
 
 test_that("get_zip_data relative paths", {
-
   on.exit(try(unlink(tmp, recursive = TRUE)), add = TRUE)
   dir.create(tmp <- tempfile())
 
@@ -92,10 +97,11 @@ test_that("get_zip_data relative paths", {
     file.path(tmp, "foo"),
     expect_equal(
       get_zip_data_path(file.path("..", "foo"), TRUE),
-      df(paste0(c(file.path("..", "foo"), file.path("..", "foo", "bar")), "/"),
-         normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
-         c(TRUE, TRUE)
-         )
+      df(
+        paste0(c(file.path("..", "foo"), file.path("..", "foo", "bar")), "/"),
+        normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
+        c(TRUE, TRUE)
+      )
     )
   )
 })
