@@ -1,4 +1,3 @@
-
 test_that("get_zip_data", {
   on.exit(try(unlink(tmp, recursive = TRUE)), add = TRUE)
   dir.create(tmp <- tempfile())
@@ -7,7 +6,10 @@ test_that("get_zip_data", {
     get_zip_data_nopath_recursive(tmp),
     df(paste0(basename(tmp), "/"), normalizePath(tmp), TRUE)
   )
-  expect_equal(get_zip_data_nopath_recursive(tmp), get_zip_data_nopath(tmp, TRUE))
+  expect_equal(
+    get_zip_data_nopath_recursive(tmp),
+    get_zip_data_nopath(tmp, TRUE)
+  )
 
   foobar <- file.path(tmp, "foobar")
   cat("foobar", file = foobar)
@@ -16,23 +18,34 @@ test_that("get_zip_data", {
     get_zip_data_nopath_recursive(foobar),
     df(basename(foobar), normalizePath(foobar), FALSE)
   )
-  expect_equal(get_zip_data_nopath_recursive(foobar), get_zip_data_nopath(foobar, TRUE))
+  expect_equal(
+    get_zip_data_nopath_recursive(foobar),
+    get_zip_data_nopath(foobar, TRUE)
+  )
 
   expect_equal(
     get_zip_data_nopath_recursive(tmp),
-    df(c(paste0(basename(tmp), "/"), file.path(basename(tmp), "foobar")),
-       normalizePath(c(tmp, foobar)),
-       c(TRUE, FALSE)
-       )
+    df(
+      c(paste0(basename(tmp), "/"), file.path(basename(tmp), "foobar")),
+      normalizePath(c(tmp, foobar)),
+      c(TRUE, FALSE)
+    )
+  )
+  expect_equal(
+    get_zip_data_nopath_recursive(tmp),
+    get_zip_data_nopath(tmp, TRUE)
   )
-  expect_equal(get_zip_data_nopath_recursive(tmp), get_zip_data_nopath(tmp, TRUE))
 
   expect_equal(
     withr::with_dir(tmp, get_zip_data_nopath_recursive(".")),
     df("foobar", normalizePath(foobar), FALSE)
   )
-  withr::with_dir(tmp,
-    expect_equal(get_zip_data_nopath_recursive("."), get_zip_data_nopath(".", TRUE))
+  withr::with_dir(
+    tmp,
+    expect_equal(
+      get_zip_data_nopath_recursive("."),
+      get_zip_data_nopath(".", TRUE)
+    )
   )
 
   dir.create(file.path(tmp, "empty"))
@@ -41,14 +54,20 @@ test_that("get_zip_data", {
   cat("bar\n", file = bar)
 
   data <- df(
-    c(paste0(basename(tmp), "/"),
+    c(
+      paste0(basename(tmp), "/"),
       paste0(file.path(basename(tmp), "empty"), "/"),
       paste0(file.path(basename(tmp), "foo"), "/"),
       file.path(basename(tmp), "foo", "bar"),
-      file.path(basename(tmp), "foobar")),
+      file.path(basename(tmp), "foobar")
+    ),
     normalizePath(c(
-      tmp, file.path(tmp, "empty"), file.path(tmp, "foo"),
-      bar, file.path(tmp, "foobar"))),
+      tmp,
+      file.path(tmp, "empty"),
+      file.path(tmp, "foo"),
+      bar,
+      file.path(tmp, "foobar")
+    )),
     c(TRUE, TRUE, TRUE, FALSE, FALSE)
   )
   data <- data[order(data$file), ]
@@ -63,16 +82,15 @@ test_that("get_zip_data", {
 
   expect_equal(
     get_zip_data_nopath(c(foobar, bar), TRUE),
-    df(c("foobar", "bar"),
-       normalizePath(c(foobar, bar)),
-       c(FALSE, FALSE))
+    df(c("foobar", "bar"), normalizePath(c(foobar, bar)), c(FALSE, FALSE))
   )
 
   expect_equal(
     get_zip_data_nopath(file.path(tmp, "foo"), TRUE),
-    df(c("foo/", "foo/bar"),
-       normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
-       c(TRUE, FALSE)
-       )
+    df(
+      c("foo/", "foo/bar"),
+      normalizePath(c(file.path(tmp, "foo"), file.path(tmp, "foo", "bar"))),
+      c(TRUE, FALSE)
+    )
   )
 })
