@@ -1,12 +1,8 @@
-
-context("zip_list")
-
 test_that("can list a zip file", {
-
   dir.create(tmp <- tempfile())
   cat("first file", file = file.path(tmp, "file1"))
   cat("second file", file = file.path(tmp, "file2"))
-  
+
   zipfile <- tempfile(fileext = ".zip")
 
   expect_silent(
@@ -17,7 +13,7 @@ test_that("can list a zip file", {
   )
 
   expect_true(file.exists(zipfile))
-  
+
   list <- zip_list(zipfile)
   expect_equal(
     basename(list$filename),
@@ -26,7 +22,23 @@ test_that("can list a zip file", {
 
   expect_equal(
     colnames(list),
-    c("filename", "compressed_size", "uncompressed_size", "timestamp",
-      "permissions")
+    c(
+      "filename",
+      "compressed_size",
+      "uncompressed_size",
+      "timestamp",
+      "permissions",
+      "crc32",
+      "offset",
+      "type"
+    )
   )
+  expect_true(is.numeric(list$offset))
+  expect_true(inherits(list$crc32, 'hexmode'))
+})
+
+test_that("symlinks", {
+  options(width = 200)
+  zf <- test_path("fixtures/symlink.zip")
+  expect_snapshot(zip_list(zf)$type)
 })
